| Package: |
| RcmdrPlugin.seeg |
| Type: |
| Package |
| Version: |
| 1.0 |
| Date: |
| 2013-01-06 |
| License: |
| GPL-2 |
To start the RcmdrPlugin.seeg:
1.- run the R Commander by loading it as package Rcmdr or by using Commander() if the Rcmdr package is already loaded
2.- select RcmdrPlugin.seeg from menu Tools -> Load Rcmdr Plug-in(s) ...
Note: once the RcmdrPlugin.seeg has been loaded, the options()$Rcmdr should show "RcmdrPlugin.seeg" in the $plugins component.
3.- during the same R session, after the RCommander is closed, it can be re-run simply with Commander() and the RcmdrPlugin.seeg will re-run directly because of the options()$Rcmdr have been set.
Optionally, if you want RcmdrPlugin.seeg to load automatically upon starting Rcmdr set options using options(Rcmdr=list(plugins="RcmdrPlugin.seeg"))
Fox, J. 2005 "The R Commander: A basic-statistics graphical user interface to R" Journal of Statistical Software, 14(9):1-42, Aug. 2005. ISSN 1548-7660. URL http://www.jstatsoft.org/v14/i09
Fox, J. 2007 "Extending the R Commander by `Plug-In' Packages." R News, 7(3), 46-52. URL http://CRAN.R-project.org/doc/Rnews/
ecdfPlot, tsPlot,
scangeoEASppp, convertToppp,
quadChisqppp, nnGKenvppp,
varCal, SemiVarCov,
OKrigingCmd, PlotKriged
panel2(size=5)
x <- rnorm(100)
ts.plot(x)
acf(x)
Run the code above in your browser using DataLab